@@ -93,14 +93,12 @@ pub enum NetworkTechnology {
 }
 
 impl NetworkTechnology {
-    pub fn parse(input: &[u8]) -> IResult<&[u8], NetworkTechnology> {
-        let (i, b) = utils::pu8(input).unwrap();
-
-        match b {
-            0 => Ok((i, NetworkTechnology::CdmaGsm)),
-            1 => Ok((i, NetworkTechnology::Umts)),
-            10 => Ok((i, NetworkTechnology::Lte)),
-            11 => Ok((i, NetworkTechnology::Reserved)),
+    pub fn parse(input: u8) -> NetworkTechnology {
+        match input {
+            0 => NetworkTechnology::CdmaGsm,
+            1 => NetworkTechnology::Umts,
+            10 => NetworkTechnology::Lte,
+            11 => NetworkTechnology::Reserved,
             _ => panic!("not found"),
         }
     }
@@ -138,28 +136,51 @@ impl fmt::Debug for NetworkTechnology {
 
 #[derive(Debug, PartialEq)]
 pub struct CommState {
+    /// Available
     pub available: bool,
+
+    /// Network service
     pub network_service: bool,
+
+    /// Data service
     pub data_service: bool,
+
+    /// Connected
     pub connected: bool,
+
+    /// Voice call active
     pub voice_call_active: bool,
+
+    /// Roaming
     pub roaming: bool,
+
+    /// Network Technology
     pub network_technology: NetworkTechnology,
 }
 
 impl CommState {
     pub fn parse(input: &[u8]) -> IResult<&[u8], CommState> {
-        let (i, _) = utils::pu8(input).unwrap();
+        #[allow(clippy::type_complexity)]
+        let (i, b): (&[u8], (u8, u8, u8, u8, u8, u8, u8)) =
+            bits::<_, _, Error<(&[u8], usize)>, _, _>(nom::sequence::tuple((
+                streaming::take(1u8),
+                streaming::take(1u8),
+                streaming::take(1u8),
+                streaming::take(1u8),
+                streaming::take(1u8),
+                streaming::take(1u8),
+                streaming::take(2u8),
+            )))(input)?;
         Ok((
             i,
             CommState {
-                available: false,
-                network_service: false,
-                data_service: false,
-                connected: false,
-                voice_call_active: false,
-                roaming: false,
-                network_technology: NetworkTechnology::CdmaGsm,
+                available: b.6 == 1,
+                network_service: b.5 == 1,
+                data_service: b.4 == 1,
+                connected: b.3 == 1,
+                voice_call_active: b.2 == 1,
+                roaming: b.1 == 1,
+                network_technology: NetworkTechnology::parse(b.0),
             },
         ))
     }
@@ -209,14 +230,29 @@ impl Inputs {
 
 #[derive(Debug, PartialEq)]
 pub struct UnitStatus {
-    ignition: bool,
-    input_1: bool,
-    input_2: bool,
-    input_3: bool,
-    input_4: bool,
-    input_5: bool,
-    input_6: bool,
-    input_7: bool,
+    /// LMU32: HTTP OTA Update Status (0=OK, 1=Error), LMU8: Unused
+    pub ota_update: bool,
+
+    /// GPS Antenna Status (0=OK, 1=Error)
+    pub gps_antenna: bool,
+
+    /// GPS Receiver Self-Test (0=OK, 1=Error) (LMU32 only)
+    pub gps_self_test: bool,
+
+    /// GPS Receiver Tracking (0=Yes, 1=No)
+    pub gps_tracking: bool,
+
+    /// Reserved, Currently Unused
+    pub reserved_1: bool,
+
+    /// Reserved, Currently Unused
+    pub reserved_2: bool,
+
+    /// Reserved, Currently Unused
+    pub reserved_3: bool,
+
+    /// Unused
+    unused: bool,
 }
 
 impl UnitStatus {
@@ -236,14 +272,14 @@ impl UnitStatus {
         Ok((
             i,
             UnitStatus {
-                ignition: b.7 == 1,
-                input_1: b.6 == 1,
-                input_2: b.5 == 1,
-                input_3: b.4 == 1,
-                input_4: b.3 == 1,
-                input_5: b.2 == 1,
-                input_6: b.1 == 1,
-                input_7: b.0 == 1,
+                ota_update: b.7 == 0,
+                gps_antenna: b.6 == 0,
+                gps_self_test: b.5 == 0,
+                gps_tracking: b.4 == 0,
+                reserved_1: b.3 == 0,
+                reserved_2: b.2 == 0,
+                reserved_3: b.1 == 0,
+                unused: b.0 == 0,
             },
         ))
     }
@@ -398,7 +434,7 @@ pub struct EventReport {
 
 impl EventReport {
     /// Parse event report
-    pub fn parse(input: &[u8]) -> IResult<&[u8], EventReport> {
+    pub fn parse(input: &[u8]) -> std::io::Result<EventReport> {
         let mut accum_list: Vec<u32> = vec![];
         let (i, update_time) = utils::pu32(input).unwrap();
         let (i, time_of_fix) = utils::pu32(i).unwrap();
@@ -426,31 +462,28 @@ impl EventReport {
             accum_list.push(v);
         }
 
-        Ok((
-            i,
-            EventReport {
-                update_time,
-                time_of_fix,
-                latitude,
-                longitude,
-                altitude,
-                speed,
-                heading,
-                satellites,
-                fix_status,
-                carrier,
-                rssi,
-                comm_state,
-                hdop,
-                inputs,
-                unit_status,
-                event_index,
-                event_code,
-                accums,
-                append,
-                accum_list,
-            },
-        ))
+        Ok(EventReport {
+            update_time,
+            time_of_fix,
+            latitude,
+            longitude,
+            altitude,
+            speed,
+            heading,
+            satellites,
+            fix_status,
+            carrier,
+            rssi,
+            comm_state,
+            hdop,
+            inputs,
+            unit_status,
+            event_index,
+            event_code,
+            accums,
+            append,
+            accum_list,
+        })
     }
 }
 
@@ -459,6 +492,7 @@ mod tests {
 
     use super::EventReport;
     use crate::message_header::MessageHeader;
+    use crate::messages::event_report::NetworkTechnology;
     use crate::options_header::OptionsHeader;
 
     #[test]
@@ -478,7 +512,7 @@ mod tests {
         ];
         let (i, _) = OptionsHeader::parse(&data).unwrap();
         let (i, _) = MessageHeader::parse(i).unwrap();
-        let (_, event_report) = EventReport::parse(i).unwrap();
+        let event_report = EventReport::parse(i).unwrap();
 
         assert_eq!(event_report.update_time, 1609644628);
         assert_eq!(event_report.time_of_fix, 1609644631);
@@ -491,13 +525,17 @@ mod tests {
         approx::assert_relative_eq!(event_report.speed, 0.0000011);
         assert_eq!(event_report.heading, 0);
         assert_eq!(event_report.satellites, 6);
-        // assert_eq!(event_report.fix_status, 0);
+        assert_eq!(event_report.fix_status.twod_fix, true);
         assert_eq!(event_report.carrier, 0);
         assert_eq!(event_report.rssi, -115);
-        // assert_eq!(event_report.comm_state, 0);
+        assert_eq!(event_report.comm_state.available, false);
+        assert_eq!(
+            event_report.comm_state.network_technology,
+            NetworkTechnology::CdmaGsm
+        );
         assert_eq!(event_report.hdop, 30);
-        // assert_eq!(event_report.inputs, 0);
-        // assert_eq!(event_report.unit_status, 0);
+        assert_eq!(event_report.inputs.ignition, false);
+        assert_eq!(event_report.unit_status.gps_antenna, true);
         assert_eq!(event_report.event_index, 123);
         assert_eq!(event_report.event_code, 33);
         assert_eq!(event_report.accums, 16);
